from setuptools import setup

setup(
    name='nesteryql',
    version='2.1.1',
    py_modules=['nesteryql'],
    author='yinql',
    author_email='yql1019@126.com',
    url='http://www.yql.com',
    description='A simple print list function',
    )